-- Latvian COA
-- prepared by Kaspars Melkis <info@isolis.lv>
-- Sept. 14, 2003
-- checked and edited Sept. 20, 2003, D. Simader
--
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1','Ilgtermia ieguldjumi','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2','Apgrozmie ldzeki','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('11','Nematerilie ieguldjumi','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('12','Pamatldzeki','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1210','Zemes gabali, kas, bves, ilggadgie stdjumi un citi nekustam pauma objekti','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1290','Pamatldzeku nolietojums (pasv)','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('13','Ilgtermia finansu ieguldjumi','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('21','Krjumi','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2130','Gatavs preces prdoanai','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2310','Norini ar pircjiem un pasttjiem','A','L','AP','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('23','Norini par prasbm (ar debitoriem)','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2350','Norini ar citiem debitoriem','A','A','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('26','Naudas ldzeki','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2610','Kase','A','A','AR_paid:AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1380','Aizdevumi uzmuma dalbniekiem un valdei','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1310','Ldzdalba meitas uzmumu kapitl','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1340','Aizdevumi saisttajiem uzmumiem','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1350','Prjie vrtspapri','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5','Kreditori','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1370','Pau akcijas un daas','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2210','Pieauguie produktvie lopi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3350','Stattos paredzts rezerves','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2220','Jaunlopi un skie dzvnieki','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2320','Par piegdm un pastjumiem saemtie veksei','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2140','Nepabeigtie pastjumi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2370','stermia aizdevumi sabiedrbm dalbniekiem un vadbai','A','A','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1360','Prjie aizdevumi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2120','Nepabeigtie raojumi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2330','Meitas uzmumu pardi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2340','Saistto uzmumu pardi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2380','Norini par prasbm pret personlu un stermia aizdevumi personlam','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2410','Nkamo periodu izdevumi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2420','Akciju emisijas  nocenojums (disagio)','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('25','Vrtspapri apgrozmo ldzeku sastv un stermia ldzdalba kapitlos','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2510','Meitas  uzmuma akcijas un daas ','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2520','Saistto uzmuma akcijas un daas ','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2530','Pau  uzmuma akcijas un daas ','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2540','Prjie vrtspapri un ldzdalba kapitlos','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2640','Akreditvi, eki un pau norina  formu konti','A','A','AR_paid:AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2650','Citi konti banks','A','A','AR_paid:AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2670','Prjie naudas ldzeki','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3','Pau kapitls','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3130','Ilgtermia ieguldjuma prvrtanas rezerve','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3120','Akciju emisijas uzcenojums (agio)','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('32','Privtkonti','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3210','Privtiem nolkiem izemtie ldzeki','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('33','Rezerves ','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3310','Rezerves kapitls','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3330','Citas likum paredzts  rezerves','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3340','Rezerves pau akcijm un dam','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3360','Prjs rezerves','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('34','Nesadalt pea vai nesegtie zaudjumi','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3410','Prskata gada nesadalt pea','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3420','Iepriekjo gadu nesadalt pea','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4','Uzkrjumi','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4110','Uzkrjumi pensijm pieldzintm saistbm','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4310','Citi uzkrjumi','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('41','Uzkrjumi pensijm pieldzinmtm saistbm','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('43','Citi uzkrjumi','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('42','Uzkrjumi paredzamiem nodokiem','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('51','Norini par aizmumiem','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5110','Aizmumi pret obligcijm','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5120','Akcijs prvamie aizmumi','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5130','Aizmumi ar ldzdalbu pe','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5140','Citi aizmumi','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5150','stermia aizmumi  no kredtiestdm','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5160','Ilgtermia aizmumi no kredtiestdm','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5170','Aizmumi no kredtiestdm bez nordt termia','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('52','Norini par saemtajiem avansiem','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5210','Norini par saemtiem avansiem','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('54','Maksjamie veksei','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('53','Norini par piegdtjiem un darbuzmjiem','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5310','Norini par piegdtjiem un darbuzmjiem','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5410','Norini par pau izdotajiem vekseiem','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5510','Norini par pardiem meitas uzmumiem','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5540','Norini par pardiem citiem uzmumiem un dalbniekiem','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5550','Norini par pardiem personlam','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5520','Norini par pardiem saisttiem uzmumiem','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5530','Norini par pardiem uzmumiem, ar kuriem ir lgums par ldzdalbu','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('57','Norini par nodokiem','H','L','AP_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('58','Norini par  dividendm','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('61','Iemumi no prdoanas, kas apliekami ar nodokiem visprj krtb','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('62','Iemumi no prdoanas, kas citdi  apliekami ar nodokiem','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6220','Ar paiem nodokiem apliekamie prdoanas iemumi','A','I','AR_amount:IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('63','Komisijas, starpniecbas un citi iemumi','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6310','Komisijas un starpniecbas iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6320','Iemumi no atkritumu prstrdes un realizcijas','A','I','AR_amount:IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6330','Iemumi no taras realizcijas','A','I','AR_amount:IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6340','Ar nodokiem neapliekamie apgrozjumi','A','I','AR_amount:IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('64','Iemumus samazinoas atlaides','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6410','Pieirts skonto atlaides','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6420','Pieirtie bonusi','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('59','Nkamo periodu iemumi','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('65','Prjie uzmuma iemumi','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6510','Iemumi no vrtspapru kursa paaugstinans','A','I','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6530','Iemumi no zemes gabalu iznomanas','A','I','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6540','Iemumi no apgrozmo ldzeku prdoanas','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6550','Iemumi no pamatldzeku iznomanas','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6560','Iemumos prskaittais rezervju un uzkrjumu samazinjums','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6570','Iepriekjo gadu nodoku samazinjums','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6580','Papildus  ieguldjumi un citi iemumi','A','I','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6590','Pau uzmuma kapitlieguldjumiem izpildtie darbi','A','I','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('67','Citu periodu iemumi, kas attiecas uz prskata periodu','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6710','Citu periodu iemumi, kas attiecas uz prskata periodu','A','I','AR_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('69','Socils infrastruktras iestu un paskumu iemumi','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6930','Sadzves paklpojumu iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6920','Komunls  saimniecbas iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('66','Gatavs produkcijas  un nepabeigto  raojumu krjumu un vrtbas  izmaias','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6610','Gatavs produkcijas krjumu un vrtbas izmaias','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6620','Nepabeigto raojumu krjumu un vrtbas  izmaias','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6630','Nepabeigto pastjumu atlikumu un vtbas izmaias','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6640','Produktvo  un darba dzvnieku ganmpulka vrtbas izmaias','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6940','Sabiedrisks dinanas iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6950','Izgltbas iestu iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6960','Medicnas iestu iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6970','Kultras un sporta ietu un paskumu iemumi','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6980','Prjie socils infrastruktras iestu un paskumu iemumi','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7','Saimniecisks darbbas izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('71','Izdevumi izejvielu, materilu un preu iepirkanai','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7110','Izejvielu un materilu iepirkanas un piegdes izdevumi','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7120','Preu iepirkanas un piegdes izdevumi','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7130','Saemts atlaides','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7140','Taras izdevumi','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7150','Muitas un ievednodevas','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7160','Prjie rjie izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7170','Samaksa par darbiem un pakalpojumiem no rienes','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7190','Pirkto materilu un preu krjumu un vrtbas izmaias','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('72','Personla izmaksas','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7210','Strdnieku algas','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7230','Socils  infrastruktras  iestu un paskumu darbinieku algas','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('73','Socils nodevas un izmaksas','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7320','Prjs socils izmaksas','A','E','AP_tax','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('74','Pamatldzeku nolietojums un citu ieguldjumu vrtbas norakstjumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7410','Nematerilo ieguldjumu vrtbas norakstana','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('75','Prjie saimniecisks darbbas  izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7510','Dabas aizsardzbas izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7530','Nodevas par raoan izmantotiem zemes gabaliem','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7440','Apgrozmo ldzeku vrtbas norakstana','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7540','Apdroinnanas maksjumi (izemot darbinieku apdroinanu)','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7550','Prjie saimniecisks darbbas izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7560','Strdnieku vervanas un apmcbas izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('76','Preu prdoanas izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7610','Iesaiojamais materils, tara','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7620','Preu transporta izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7630','Preu transporta apdroinana','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7640','Samaksts komisijas naudas','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7650','Citi prdoanas izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('77','Administrcijas izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7710','Sakaru izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7720','Kantora (biroja) izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7730','Juristu pakalpojumu apmaksa','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7740','Gada prskata un revzijas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7750','Naudas apgrozjuma blakus izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7760','Transporta izdevumi administrcijas vajadzbm','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7770','Citi vadanas un administrcijas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('78','Prskata period iekaujamie iepriekjo periodu izdevumi','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7810','Prskata period iekaujamie iepriekjo periodu izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('79','Socils  infrastruktras uzturanas izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7920','Komuls saimniecbas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7940','Sabiedrisks dinanas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7950','Izgltbas iestu izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8','Dadi iemumi un izdevumi, pea un zaudjumi','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('81','Dadi iemumi','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8110','Iemumi no ldzdalbas, vrtspapriem un aizdevumiem','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8120','Prjie iemumi no procentiem un tiem pieldzinmi iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7910','Dzvoku saimniecbas izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8130','Vekseu diskonta iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8150','Ienkumi no valtas kursa paaugstinans','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8160','Saemts soda naudas un lgumsodi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8170','Pea no rzemju valtas prdoanas vai pirkanas','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8190','Citi iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('82','Dadi izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8210','stermia finansu ieguldjumu vrtbas norakstana','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8220','Samakstie procenti un tiem pieldzinmie izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8230','Vekseu diskonta izmaksas','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8240','Ilgtermia aizdevumu procentu samaksa','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8260','Samaksts soda naudas un lgumsodi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8270','Zaudjumi no rzemju valtas pirkanas un prdoanas','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8290','Citi izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('83','rkrtas iemumi','H','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8310','rkrtas iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('84','rkrtas izdevumi','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8410','rkrtas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('86','Pea vai zaudjumi','H','I','IC_income:IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8610','Pea vai zaudjumi','A','I','IC_income:IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3220','Privtie ieguldjumi','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6110','Iemumi no pamatdarbbas  produkcijas un pakalpojumu prdoanas','A','I','AR_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1220','Tehnoloisks  iekrtas un manas','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1240','Pamatldzeku izveidoana un nepabeigto celtniecbas objektu izmaksas','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1320','Aizdevumi meitas uzmumam','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2110','Izejvielas un materili','A','A','AP','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2190','Avansa maksjumi par precm','A','A','AR','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1130','Uzmuma nemateril vrtba','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1180','Avansa maksjumi par nemateriliem aktviem','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1190','Nematerilo ieguldjumu vrtbas norakstt daa (pasv)','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('22','Produktvie un darba dzvnieki','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2230','Darba lopi','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2290','Darba lopu norakstt vrtba (pasv)','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2360','Norini par parakstt sabiedrbas kapitl neiemakstm summm','A','A','AR_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('24','Nkamo periodu izdevumi','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2620','Norinu konti bank','A','A','AR_paid:AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3110','Pamatkapitls vai ldzdalbas kapitls','A','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('55','Norini ar uzmumiem, dalbniekiem un personlu','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('56','Norini  par darba samaksu  un ieturjumiem (izemot nodokus)','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5610','Norini par darba algu','A','E','AP_amount','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5620','Norini par ieturjumiem no darba algas (izemot nodokus)','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5820','Norini par iepriekjo gadu neizmakstajm dividendm','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5810','Norini par prskata gada dividendm','A','L','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5910','Nkamo periodu iemumi','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6','Iemumi no uzmuma saimniecisks darbbas','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6210','Ar nodokiem neapliekamie prdoanas iemumi','A','I','AR_amount:IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6430','Pieirtie rabati un citas tirdzniecbas  atlaides','A','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6910','Dzvoku saimniecbas iemumi','A','I','AR_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7180','Prjie materilie izdevumi (nodoklis par dabas resursu izmantoanu, celmu nauda u.c.)','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7240','Prjs personla izmaksas','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7220','Prvaldes personla un administratv personla algas','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7420','Pamatldzeku nolietojums','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7570','Komandjuma izdevumi','A','E','AP_paid','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7930','Sadzves pakalpojumu izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7960','Medicnisks apkalpoanas izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7970','Kultras un sporta iestu un paskumu izdevumi','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8140','Ziedojumi un citi tiem pieldzinmi iemumi','A','I','IC_income','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8250','Zaudjumi no valtu  kursa pazeminans','A','E','IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7980','Prjie socils infrastruktras uzturanas izdevumi','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('87','Peas izlietojums (bez nodokiem)','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('88','Nodoi no peas un citi saimniecisks darbbas izdevumos neiekaujamie nodoki','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1110','Ptniecbas un uzmuma attstbas izmaksas','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1120','Koncesijas, patenti, licences, tirdzniecbas zmes un ldzgas tiesbas; datoru programmas','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1230','Prjie pamatldzeki un inventrs','A','A','IC','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5710','Norini par peas nodokli','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2390','Prmakstie nodoki, iepriek samakstie nodoki','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4210','Uzkrjumi paredzamiem nodokiem','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5720','Norini par citiem nodokiem, nodevm un maksjumiem budetam','A','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7310','Socilais nodoklis','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8710','Peas izlietojums','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8830','Nodoklis par zemi','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8840','Citi saimniecisks darbbas izmakss neiekaujamie nodoki','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8820','Nodoklis par dabas resursu izmantoanu no peas  maksjam da','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8810','Nodoklis no peas','A','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1330','Ldzdalbas saistto uzmumu kapitl','A','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2354','PVN samaksts 18%','A','E','AP_tax:IC_taxpart:IC_taxservice:CT_tax','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2352','PVN ieemtais 18%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','');
--
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart where accno = '2352'),'0.18','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart where accno = '2354'),'0.18','');
--
update defaults set inventory_accno_id = (select id from chart where accno = '1230'), income_accno_id = (select id from chart where accno = '6010'), expense_accno_id = (select id from chart where accno = '7110'), fxgain_accno_id = (select id from chart where accno = '8170'), fxloss_accno_id = (select id from chart where accno = '8270'), curr = 'LVL', weightunit = 'kg';

